/*
 * Copyright 2005-2006 Myriad Genetics, Inc.
 *
 * All rights reserved.
 */

#include "genmap.h"
#include "input.h"
#include "output.h"
#include "ped.h"
#include "Phasing.h"
#include <stdlib.h>
#include <stdio.h>

#define INITIAL_LOD_THRESH 3.0
#define USAGE_STRING "usage: %s <input file> <output file> [<lod thresh>]\n"

int main(int argc, char **argv)
{
    double          lodThresh = 0.0;
    const char      *inFile;
    const char      *outFile;
    pedigree_t      ped;
    bool            varyThresh;
    
    if (argc == 3) {
        varyThresh = true;
    } else if (argc == 4) {
        char    *endp;
        
        varyThresh = false;
        
        lodThresh = strtod(argv[3], &endp);
        if (*endp != '\0') {
            fprintf(stderr, "%s: The lod threshold %s is not a valid number\n",
                    *argv, argv[3]);
            fprintf(stderr, USAGE_STRING, *argv);
            return EXIT_FAILURE;
        }
    } else {
        fprintf(stderr, USAGE_STRING, argv[0]);
        return EXIT_FAILURE;
    }
    
    inFile = argv[1];
    outFile = argv[2];
    
    if (!readFile(&ped, inFile))
        return EXIT_FAILURE;
    
    if (varyThresh) {
        lodThresh = phasingVary(&ped, INITIAL_LOD_THRESH);
        printf("Used a LOD threshold of %.4f\n", lodThresh);
        writePed(&ped, outFile);
    } else {
        if (phasing(&ped, lodThresh))
            writePed(&ped, outFile);
        else {
            printf("Could not determine the phases. ");
            printf("Try using a higher LOD threshold.\n");
        }
    }
    
    freePed(&ped);
    return EXIT_SUCCESS;
}
