/*
 * Copyright 2005-2006 Myriad Genetics, Inc.
 *
 * All rights reserved.
 */

#include "output.h"
#include <stdio.h>

/* Writes the information in ped into the file fname. It always uses the "f2
   intercross" format for the data, because it is the most general. However,
   the resulting files are kind of obscure to a human. */
void writePed(pedigree_t *ped, const char *fname)
{
    FILE    *fp = fopen(fname, "w");
    int     i, j;
    
    if (fp == NULL) {
        fprintf(stderr, "Could not open %s for writing\n", fname);
        return;
    }
    
    fprintf(fp, "data type f2 intercross\n%d %d\n", ped->numInds,ped->numMarks);
    
    for (i = 0; i < ped->numMarks; ++i) {
        fprintf(fp, "*%s ", ped->markers[i].name);
        
        for (j = 0; j < ped->numInds; ++j) {
            obs_t   obs = ped->markers[i].obs[j];
            if (obs == OBSERVATION_UNKNOWN)
                fputc('-', fp);
            else
                fprintf(fp, "%x", ped->markers[i].obs[j]);
        }
        
        fputc('\n', fp);
    }
    
    fclose(fp);
}
